@@ -38,8 +38,8 @@ class DefaultUnleashConf(Configuration):
         url=os.getenv("AEXP_UNLEASH_URL"),
         app_name=os.getenv("AEXP_UNLEASH_APP_NAME"),
         custom_headers={'Authorization': os.getenv('AEXP_UNLEASH_AUTH_HEADER')},
-        refresh_interval=int(os.getenv("AEXP_UNLEASH_REFRESH_INTERVAL"), 900),
-        metrics_interval=int(os.getenv("AEXP_UNLEASH_METRICS_INTERVAL"), 900),
+        refresh_interval=int(os.getenv("AEXP_UNLEASH_REFRESH_INTERVAL", 900)),
+        metrics_interval=int(os.getenv("AEXP_UNLEASH_METRICS_INTERVAL", 900)),
         verbose_log_level=logging.INFO if os.getenv(
             "AEXP_UNLEASH_LOG_LEVEL", "info") == "info" else logging.DEBUG,
         cache_directory=os.getenv("AEXP_UNLEASH_CACHE_DIR"),
