@@ -33,12 +33,16 @@ class MixpanelExperimentConfiguration(Configuration):
 
 class MixpanelExperimentSerializer(SinkSerializer):
     def serialize(self, element, **kwargs):
+        variant = 'default'
+        if 'variant' in element.keys():
+            variant = element['variant']['name']
+        
         return dict(
             distinct_id=element['context']['userId'],
             event_name='$experiment_started',
             properties={
                 'Experiment name': element['feature'],
-                'Variant name': element['variant']['name'],
+                'Variant name': variant,
             },
             timestamp=time.time()
         )
@@ -65,7 +69,7 @@ class MixpanelExperimentSink(Sink):
             self.client = Mixpanel(
                 conf['api_token'], consumer=custom_buffered_consumer)
 
-            logging.info('MixpanelExperimentSink initialzed!')
+            logging.info(f'MixpanelExperimentSink initialzed with batch size: {custom_buffered_consumer._max_size}')
         else:
             logging.warning('MixpanelExperimentSink is already initialized!')
 
@@ -73,8 +77,20 @@ class MixpanelExperimentSink(Sink):
         """This is a custom destructor for this sink in order to flush all the events
         present in the mixpanel's buffer before terminating the object/program.
         """
-        logging.warning(f'Flushing all the events in the buffer to mixpanel.')
-        self.client._consumer.flush()
+        logging.warning(f'MixpanelSink destructor called. Now flushing the events.')
+        self.flush()
+        logging.warning('Done, now destroying MixpanelSink')
+        
+        
+    def flush(self):
+        num_events = len(self.client._consumer._buffers["imports"])
+        if num_events > 0:
+            logging.warning(f'Flushing {num_events} events in the buffer to mixpanel.')
+            self.client._consumer.flush()
+            logging.warning(f'Flushed.')
+        else:
+            logging.info(f'No events was there to flush in MixpanelSink.')
+            return
 
     def push(self, element: dict, **kwargs) -> bool:
         """This method calls the import_data method of the mixpanel client to send around 2000 events per API
@@ -104,7 +120,7 @@ class MixpanelExperimentSink(Sink):
     def bulk_push(self, serialized_elements: List[dict]) -> bool:
         raise NotImplementedError(
             f'This function is not implemented and not required in RudderstackSink.')
-
+        
     def trigger(self):
         raise NotImplementedError(
             f'This function is not implemented and not required in RudderstackSink.')
